embassy-usb-dfu

Crates

git

Versions

dfu

Flavors

Status

Enum Status 

#[repr(u8)]
pub enum Status {
Show 16 variants Ok = 0, ErrTarget = 1, ErrFile = 2, ErrWrite = 3, ErrErase = 4, ErrCheckErased = 5, ErrProg = 6, ErrVerify = 7, ErrAddress = 8, ErrNotDone = 9, ErrFirmware = 10, ErrVendor = 11, ErrUsbr = 12, ErrPor = 13, ErrUnknown = 14, ErrStalledPkt = 15,
}
DFU status codes indicating the result of the most recent request.

Variants



Ok = 0

No error.



ErrTarget = 1

File is not targeted for use by this device.



ErrFile = 2

File is for this device but fails some vendor-specific verification test.



ErrWrite = 3

Device is unable to write memory.



ErrErase = 4

Memory erase function failed.



ErrCheckErased = 5

Memory erase check failed.



ErrProg = 6

Program memory function failed.



ErrVerify = 7

Programmed memory failed verification.



ErrAddress = 8

Cannot program memory due to received address that is out of range.



ErrNotDone = 9

Received DFU_DNLOAD with wLength = 0, but device does not think it has all of the data yet.



ErrFirmware = 10

Device’s firmware is corrupt. It cannot return to run-time (non-DFU) operations.



ErrVendor = 11

iString indicates a vendor-specific error.



ErrUsbr = 12

Device detected unexpected USB reset signaling.



ErrPor = 13

Device detected unexpected power on reset.



ErrUnknown = 14

Something went wrong, but the device does not know what.



ErrStalledPkt = 15

Device stalled an unexpected request.